==> ejc-jltest-impl-3.0.0-20240311.091845-55-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlancDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 安措费使用计划C明细
 *
 * @author generator
 */
@TableName("ejc_jltest_planc_detail")
public class PlancDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "plan_id")
    private Long planId; // 主表主键ID
    @TableField(value = "detail_name")
    private String detailName; // 安全费用项目名称
    @TableField(value = "detail_mny")
    private BigDecimal detailMny; // 拟投入金额（万元）
    @TableField(value = "detail_date")
    private Date detailDate; // 使用时间
    @TableField(value = "detail_memo")
    private String detailMemo; // 安措费使用计发文说明


    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }

    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }

    public Date getDetailDate() {
        return detailDate;
    }

    public void setDetailDate(Date detailDate) {
        this.detailDate = detailDate;
    }

    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }

}

==> ejc-jltest-impl-3.0.0-20240328.015927-125-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlancDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 安措费使用计划C明细
 *
 * @author generator
 */
@TableName("ejc_jltest_planc_detail")
public class PlancDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "plan_id")
    private Long planId; // 主表主键ID
    @TableField(value = "detail_name")
    private String detailName; // 安全费用项目名称
    @TableField(value = "detail_mny")
    private BigDecimal detailMny; // 拟投入金额（万元）

    @TableField(value = "detail_max_mny")
    private BigDecimal detailMaxMny; // 最大拟投入金额
    @TableField(value = "detail_org_id")
    private Long detailOrgId; // 组织Id
    @TableField(value = "detail_org_name")
    private String detailOrgName; // 组织名称
    @TableField(value = "detail_org_type")
    private Integer detailOrgType; // 组织类型
    @TableField(value = "detail_date")
    private Date detailDate; // 使用时间
    @TableField(value = "detail_memo")
    private String detailMemo; // 安措费使用计发文说明


    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }

    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }

    public Date getDetailDate() {
        return detailDate;
    }

    public void setDetailDate(Date detailDate) {
        this.detailDate = detailDate;
    }

    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }

    public BigDecimal getDetailMaxMny() {
        return detailMaxMny;
    }

    public void setDetailMaxMny(BigDecimal detailMaxMny) {
        this.detailMaxMny = detailMaxMny;
    }

    public Long getDetailOrgId() {
        return detailOrgId;
    }

    public void setDetailOrgId(Long detailOrgId) {
        this.detailOrgId = detailOrgId;
    }

    public String getDetailOrgName() {
        return detailOrgName;
    }

    public void setDetailOrgName(String detailOrgName) {
        this.detailOrgName = detailOrgName;
    }

    public Integer getDetailOrgType() {
        return detailOrgType;
    }

    public void setDetailOrgType(Integer detailOrgType) {
        this.detailOrgType = detailOrgType;
    }
}
